# Lexicon

This is a Verilog Project Manager.

This documentation consists of different parts. To go to one click one of the following:

- [`Project Specification`](Project/README.md)

    This descrbes the project specification of the project-manager.

## Installation

For Install Instructions, Click [here](INSTALL.md)

## License

Copyright (c) 2021 Goutham Krishna K V

All rights reserved, as per defined by [MIT License](../LICENSE)
